import { ValidationError } from "./sanitize";
import { NO_HOSTNAME } from "./from-url";
export declare const RESERVED_TOP_LEVEL_DOMAINS: string[];
export declare type Label = string;
export declare enum ParseResultType {
    /**
     * This parse result is returned in case the given hostname does not adhere to [RFC 1034](https://tools.ietf.org/html/rfc1034).
     */
    Invalid = "INVALID",
    Reserved = "RESERVED",
    NotListed = "NOT_LISTED",
    Listed = "LISTED"
}
declare type ParseResultCommon<Type extends ParseResultType> = {
    /**
     * The type of the parse result. Use switch or if to distinguish between different results.
     */
    type: Type;
    /**
     * The original hostname that was passed to parseDomain().
     */
    hostname: Type extends ParseResultType.Invalid ? string | typeof NO_HOSTNAME : string;
};
export declare type ParseResultInvalid = ParseResultCommon<ParseResultType.Invalid> & {
    /**
     * An array of validation errors.
     */
    errors: Array<ValidationError>;
};
declare type ParseResultCommonValid = {
    /**
     * An array with labels that were separated by a dot character in the given hostname.
     */
    domains: Array<Label>;
};
export declare type ParseResultReserved = ParseResultCommon<ParseResultType.Reserved> & ParseResultCommonValid;
export declare type ParseResultNotListed = ParseResultCommon<ParseResultType.NotListed> & ParseResultCommonValid;
declare type ParseResultListedDomains = ParseResultCommonValid & {
    /**
     * An array of labels that belong to the subdomain. Can be empty if there was no subdomain in the given hostname.
     */
    subDomains: Array<Label>;
    /**
     * The first label that belongs to the user-controlled section of the hostname. Can be undefined if just a top-level domain was passed to parseDomain().
     */
    domain: Label | undefined;
    /**
     * An array of labels that are controlled by the domain registrar.
     */
    topLevelDomains: Array<Label>;
};
export declare type ParseResultListed = ParseResultCommon<ParseResultType.Listed> & ParseResultListedDomains & {
    /**
     * The parse result according to ICANN only without private top-level domains.
     */
    icann: ParseResultListedDomains;
};
export declare type ParseResult = ParseResultInvalid | ParseResultReserved | ParseResultNotListed | ParseResultListed;
/**
 * Splits the given hostname in topLevelDomains, a domain and subDomains.
 */
export declare const parseDomain: (input: string | typeof NO_HOSTNAME) => ParseResult;
export {};
